@@ -5,7 +5,6 @@
 #include "sniprotocolhandler.h"
 #include "abstracttrayprotocol.h"
 #include "statusnotifieriteminterface.h"
-
 #include "util.h"
 #include "plugin.h"
 
@@ -22,7 +21,6 @@ DGUI_USE_NAMESPACE
 
 namespace tray {
 static QString sniPfrefix = QStringLiteral("SNI:");
-
 class DBusMenu : public DBusMenuImporter {
 public:
     DBusMenu(const QString &service, const QString &path, DBusMenuImporterType type, QObject *parent = 0)
@@ -78,6 +76,11 @@ void SniTrayProtocol::registedItemChanged()
     for (auto currentRegistedItem : currentRegistedItems) {
         if (!m_registedItem.contains(currentRegistedItem)) {
             auto trayHandler = QSharedPointer<SniTrayProtocolHandler>(new SniTrayProtocolHandler(currentRegistedItem));
+            uint pid = QDBusConnection::sessionBus().interface()->servicePid(SniTrayProtocolHandler::serviceAndPath(currentRegistedItem).first).value();
+            m_item2Pid[currentRegistedItem] = pid;
+            if (registeredMap[pid] != SNI)
+                emit removeXEmbedItemByPid(pid);
+            registeredMap[pid] = SNI;
             m_registedItem.insert(currentRegistedItem, trayHandler);
             Q_EMIT AbstractTrayProtocol::trayCreated(trayHandler.get());
         }
@@ -86,6 +89,9 @@ void SniTrayProtocol::registedItemChanged()
     for (auto alreadyRegistedItem : m_registedItem.keys()) {
         if (!currentRegistedItems.contains(alreadyRegistedItem)) {
             if (auto value = m_registedItem.value(alreadyRegistedItem, nullptr)) {
+                uint pid = m_item2Pid[alreadyRegistedItem];
+                m_item2Pid.remove(alreadyRegistedItem);
+                registeredMap.remove(pid);
                 m_registedItem.remove(alreadyRegistedItem);
             }
         }
@@ -220,7 +226,7 @@ bool SniTrayProtocolHandler::enabled() const
 
 bool SniTrayProtocolHandler::eventFilter(QObject *watched, QEvent *event)
 {
-    if (watched == parent()) {
+    if (watched == window()) {
         if (event->type() == QEvent::MouseButtonRelease) {
             QMouseEvent* mouseEvent = static_cast<QMouseEvent*>(event);
             if (mouseEvent->button() == Qt::LeftButton) {
